summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTed Trask <ttrask01@yahoo.com>2013-11-19 20:54:54 +0000
committerTed Trask <ttrask01@yahoo.com>2013-11-19 20:54:54 +0000
commit45d5efe73a0cd8091675a8ddb3ca3d95a4bc2080 (patch)
treee9c19e2e61969690d425335065f81d2d512c3ad6
parent56e25665b1d7e3438b4fa9854db6a15ce5e51295 (diff)
downloadacf-skins-45d5efe73a0cd8091675a8ddb3ca3d95a4bc2080.tar.bz2
acf-skins-45d5efe73a0cd8091675a8ddb3ca3d95a4bc2080.tar.xz
Add alps.js and change tablesorter theme for several skins
-rw-r--r--Makefile5
-rw-r--r--alps/alps.css2
-rw-r--r--alps/alps.js4
-rwxr-xr-xclouds/clouds.css2
-rw-r--r--clouds/clouds.js4
-rw-r--r--ice/ice.css2
-rw-r--r--ice/ice.js4
-rw-r--r--snow/snow.css2
-rw-r--r--snow/snow.js4
9 files changed, 14 insertions, 15 deletions
diff --git a/Makefile b/Makefile
index b53958b..ce522de 100644
--- a/Makefile
+++ b/Makefile
@@ -20,14 +20,13 @@ WWW_DIST=\
static/tango/16x16/actions/list*.png \
static/tango/16x16/actions/go*.png \
static/tango/16x16/actions/document-properties.png \
- alps/*.jpg \
- alps/*.css \
+ alps/* \
ice/* \
snow/* \
clouds/* \
wik/wik.css \
wik/wik.js \
- wik/images/*
+ wik/images/* \
EXTRA_DIST=README Makefile config.mk
diff --git a/alps/alps.css b/alps/alps.css
index 6b654f0..da479f7 100644
--- a/alps/alps.css
+++ b/alps/alps.css
@@ -4,7 +4,7 @@
* JQUERY TABLESORTER
*--------------------------------------------------------------------------------*/
-@import "../static/tablesorter/theme.blue.css";
+@import "../static/tablesorter/theme.ice.css";
/*----------------------------------------------------------------------------------
* GENERAL
diff --git a/clouds/clouds.css b/clouds/clouds.css
index eb2d1c4..1c1a580 100755
--- a/clouds/clouds.css
+++ b/clouds/clouds.css
@@ -4,7 +4,7 @@
* JQUERY TABLESORTER
*--------------------------------------------------------------------------------*/
-@import "../static/tablesorter/theme.blue.css";
+@import "../static/tablesorter/theme.default.css";
/*----------------------------------------------------------------------------------
* GENERAL
diff --git a/ice/ice.css b/ice/ice.css
index bf29710..d88a92c 100644
--- a/ice/ice.css
+++ b/ice/ice.css
@@ -14,7 +14,7 @@
* JQUERY TABLESORTER
*--------------------------------------------------------------------------------*/
-@import "../static/tablesorter/theme.blue.css";
+@import "../static/tablesorter/theme.default.css";
/*----------------------------------------------------------------------------------
* GENERAL
diff --git a/snow/snow.css b/snow/snow.css
index 9413ffe..09296ac 100644
--- a/snow/snow.css
+++ b/snow/snow.css
@@ -5,7 +5,7 @@
* JQUERY TABLESORTER
*--------------------------------------------------------------------------------*/
-@import "../static/tablesorter/theme.blue.css";
+@import "../static/tablesorter/theme.default.css";
/*
* -----------------------------------------------------------------------
diff --git a/snow/snow.js b/snow/snow.js
index 07c7e76..8d8b252 100644
--- a/snow/snow.js
+++ b/snow/snow.js
@@ -1,5 +1,5 @@
-// Add tablesorter-blue class to .tablesorter objects
+// Add tablesorter-defalut class to .tablesorter objects
// Note: you must load jquery before loading this file
$(document).ready(function() {
- $(".tablesorter").addClass("tablesorter-blue");
+ $(".tablesorter").addClass("tablesorter-default");
});
diff --git a/alps/alps.js b/alps/alps.js
index 07c7e76..01e9142 100644
--- a/alps/alps.js
+++ b/alps/alps.js
@@ -1,5 +1,5 @@
// Add tablesorter-blue class to .tablesorter objects
// Note: you must load jquery before loading this file
$(document).ready(function() {
- $(".tablesorter").addClass("tablesorter-blue");
+ $(".tablesorter").addClass("tablesorter-ice");
});
@@ -1,5 +1,5 @@
-// Add tablesorter-blue class to .tablesorter objects
+// Add tablesorter-ice class to .tablesorter objects
// Note: you must load jquery before loading this file
$(document).ready(function() {
diff --git a/clouds/clouds.js b/clouds/clouds.js
index 07c7e76..6eb1a97 100644
--- a/clouds/clouds.js
+++ b/clouds/clouds.js
@@ -1,5 +1,5 @@
// Add tablesorter-blue class to .tablesorter objects
// Note: you must load jquery before loading this file
$(document).ready(function() {
- $(".tablesorter").addClass("tablesorter-blue");
+ $(".tablesorter").addClass("tablesorter-default");
});
@@ -1,5 +1,5 @@
-// Add tablesorter-blue class to .tablesorter objects
+// Add tablesorter-default class to .tablesorter objects
// Note: you must load jquery before loading this file
$(document).ready(function() {
diff --git a/ice/ice.js b/ice/ice.js
index 07c7e76..6eb1a97 100644
--- a/ice/ice.js
+++ b/ice/ice.js
@@ -1,5 +1,5 @@
// Add tablesorter-blue class to .tablesorter objects
// Note: you must load jquery before loading this file
$(document).ready(function() {
- $(".tablesorter").addClass("tablesorter-blue");
+ $(".tablesorter").addClass("tablesorter-default");
});
@@ -1,5 +1,5 @@
-// Add tablesorter-blue class to .tablesorter objects
+// Add tablesorter-default class to .tablesorter objects
// Note: you must load jquery before loading this file
$(document).ready(function() {